summaryrefslogtreecommitdiffstats
path: root/configserver
diff options
context:
space:
mode:
authorHarald Musum <musum@oath.com>2018-09-19 08:21:24 +0200
committerHarald Musum <musum@oath.com>2018-09-19 08:21:24 +0200
commit13ecac15646d53760a9267b3a98bc3fc12dab74f (patch)
tree4a0f91ac91d85aace6bb5529b088ecc8a6f213eb /configserver
parentb38fc011d4a5cdcdbdb5d71ca77252502957fa92 (diff)
Check service config generations in parallel
Diffstat (limited to 'configserver')
-rw-r--r--configserver/src/main/java/com/yahoo/vespa/config/server/ApplicationRepository.java4
-rw-r--r--configserver/src/main/java/com/yahoo/vespa/config/server/application/ConfigConvergenceChecker.java6
2 files changed, 5 insertions, 5 deletions
diff --git a/configserver/src/main/java/com/yahoo/vespa/config/server/ApplicationRepository.java b/configserver/src/main/java/com/yahoo/vespa/config/server/ApplicationRepository.java
index 6c67f730f60..3e11637b801 100644
--- a/configserver/src/main/java/com/yahoo/vespa/config/server/ApplicationRepository.java
+++ b/configserver/src/main/java/com/yahoo/vespa/config/server/ApplicationRepository.java
@@ -477,8 +477,8 @@ public class ApplicationRepository implements com.yahoo.config.provision.Deploye
return convergeChecker.checkService(getApplication(applicationId), hostAndPort, uri, timeout);
}
- public HttpResponse servicesToCheckForConfigConvergence(ApplicationId applicationId, URI uri, Duration timeout) {
- return convergeChecker.servicesToCheck(getApplication(applicationId), uri, timeout);
+ public HttpResponse servicesToCheckForConfigConvergence(ApplicationId applicationId, URI uri, Duration timeoutPerService) {
+ return convergeChecker.servicesToCheck(getApplication(applicationId), uri, timeoutPerService);
}
// ---------------- Logs ----------------------------------------------------------------
diff --git a/configserver/src/main/java/com/yahoo/vespa/config/server/application/ConfigConvergenceChecker.java b/configserver/src/main/java/com/yahoo/vespa/config/server/application/ConfigConvergenceChecker.java
index 0f507624188..113b57328a3 100644
--- a/configserver/src/main/java/com/yahoo/vespa/config/server/application/ConfigConvergenceChecker.java
+++ b/configserver/src/main/java/com/yahoo/vespa/config/server/application/ConfigConvergenceChecker.java
@@ -60,7 +60,7 @@ public class ConfigConvergenceChecker extends AbstractComponent {
this.stateApiFactory = stateApiFactory;
}
- /** Check all services in given application */
+ /** Check all services in given application. Returns the minimum current generation of all services */
public ServiceListResponse servicesToCheck(Application application, URI requestUrl, Duration timeoutPerService) {
List<ServiceInfo> servicesToCheck = new ArrayList<>();
application.getModel().getHosts()
@@ -102,9 +102,9 @@ public class ConfigConvergenceChecker extends AbstractComponent {
StateApi createStateApi(Client client, URI serviceUri);
}
/** Get service generation for a list of services. Returns the minimum generation of all services */
private Map<ServiceInfo, Long> getServiceGenerations(List<ServiceInfo> services, Duration timeout) {
- return services.stream()
+ return services.parallelStream()
.collect(Collectors.toMap(service -> service,
service -> {
try {
@@ -102,9 +102,9 @@ public class ConfigConvergenceChecker extends AbstractComponent {
StateApi createStateApi(Client client, URI serviceUri);
}
- /** Get service generation for a list of services. Returns the minimum generation of all services */
+ /** Gets service generation for a list of services (in parallel). */
private Map<ServiceInfo, Long> getServiceGenerations(List<ServiceInfo> services, Duration timeout) {